@@ -1,5 +1,7 @@
 import pyqtgraph as pg
 import gc, os
+import pytest
+
 
 app = pg.mkQApp()
 
@@ -11,7 +13,8 @@ def test_isQObjectAlive():
     gc.collect()
     assert not pg.Qt.isQObjectAlive(o2)
 
-
+@pytest.mark.skipif(pg.Qt.USE_PYSIDE, reason='pysideuic does not appear to be '
+                                             'packaged with conda')
 def test_loadUiType():
     path = os.path.dirname(__file__)
     formClass, baseClass = pg.Qt.loadUiType(os.path.join(path, 'uictest.ui'))
@@ -20,4 +23,3 @@ def test_loadUiType():
     ui.setupUi(w)
     w.show()
     app.processEvents()
-
